@@ -1,6 +1,7 @@
-# ClamTk, copyright (C) 2004-2016 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
-# This file is part of ClamTk (https://dave-theunsub.github.io/clamtk).
+# This file is part of ClamTk
+# (https://gitlab.com/dave_m/clamtk/).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -24,7 +25,7 @@ use Encode 'decode';
 
 sub get_TK_version {
     # Stick with %.2f format - 4.50 vice 4.5
-    return '5.23';
+    return '6.10';
 }
 
 sub get_path {
@@ -86,14 +87,28 @@ sub get_path {
 
     # Most times freshclam is under /usr/bin
     $path->{ freshclam }
-        = ( -e '/usr/bin/freshclam' ) ? '/usr/bin/freshclam'
+        = ( -e '/usr/bin/freshclam' )       ? '/usr/bin/freshclam'
         : ( -e '/usr/local/bin/freshclam' ) ? '/usr/local/bin/freshclam'
         : ( -e '/opt/local/bin/freshclam' ) ? '/opt/local/bin/freshclam'
         :                                     '';
 
+    # Most times freshclam.conf is under /etc
+    # If Update eq "shared":
+    $path->{ systemfreshclamconf }
+        = ( -e '/etc/freshclam.conf' )
+        ? '/etc/freshclam.conf'
+        : '';
+
+    # Local freshclam.conf is under ~/.clamtk/db/
+    # If Update eq "single":
+    $path->{ localfreshclamconf } = "$path->{db}/local.conf";
+    #= ( -e "$path->{ db }/local.conf" )
+    # ? "$path->{ db }/local.conf"
+    # : '';
+
     # Use sigtool for db info
     $path->{ sigtool }
-        = ( -e '/usr/bin/sigtool' ) ? '/usr/bin/sigtool'
+        = ( -e '/usr/bin/sigtool' )       ? '/usr/bin/sigtool'
         : ( -e '/usr/local/bin/sigtool' ) ? '/usr/local/bin/sigtool'
         : ( -e '/opt/local/bin/sigtool' ) ? '/opt/local/bin/sigtool'
         :                                   '';
@@ -102,7 +117,7 @@ sub get_path {
     # We'll use clampath as the actual path
     # and clamscan as clampath + scan options
     $path->{ clampath }
-        = ( -e '/usr/bin/clamscan' ) ? '/usr/bin/clamscan'
+        = ( -e '/usr/bin/clamscan' )       ? '/usr/bin/clamscan'
         : ( -e '/usr/local/bin/clamscan' ) ? '/usr/local/bin/clamscan'
         : ( -e '/opt/local/bin/clamscan' ) ? '/opt/local/bin/clamscan'
         :                                    '';
@@ -333,7 +348,7 @@ sub get_sigtool_info {
         $regex = qr|Signatures: (\d+)|;
     }
 
-    my $result = '';
+    my $result  = '';
     my $sigtool = get_path( undef, 'sigtool' );
 
     my $daily_path = get_daily_sigs_path();
